@@ -1,10 +1,18 @@
+import os
 import logging
 import typing
 from constructs import Construct
 from aws_cdk import (
     Stack,
     aws_ssm,
+    aws_iam,
+    aws_lambda,
     aws_codestarconnections,
+    aws_codestarnotifications,
+    aws_codepipeline,
+    aws_codepipeline_actions,
+    aws_sns,
+    aws_sns_subscriptions,
     pipelines
 )
 from .connections import GithubConnection
@@ -12,6 +20,7 @@ from .sources import github_url_split
 
 
 class CodePipelineStack(Stack):
+    _notif_github_statuses: aws_lambda.Function=None
     _connections: typing.Dict[str, aws_codestarconnections.CfnConnection]={}
     _sources: typing.Dict[str, pipelines.CodePipelineSource]={}
     codepipeline: pipelines.CodePipeline=None
@@ -43,8 +52,8 @@ class CodePipelineStack(Stack):
     def connections(self, values: dict) -> None:
         self._connections = {}
         for name, connection in values.items():
-            if not connection.startswith('arn:aws:codestar-connections'):
-                logging.warning(f"{name} not a CS arn {connection}")
+            if not connection.startswith('arn:aws:codestar-connections') and not connection.startswith('dummy-value-for-'):
+                logging.warning(f"{name} not a CS arn {connection} - {self.is_construct()}")
             self._connections[name] = connection
 
     def add_connections(self, values: dict) -> typing.Dict[str, aws_codestarconnections.CfnConnection]:
@@ -118,3 +127,54 @@ class CodePipelineStack(Stack):
                 'cdk synth'
             ]
         return pipelines.ShellStep(id, **synth)
+
+    def enable_notif_github_statuses(self, codepipeline: pipelines.CodePipeline):
+        # Build pipeline
+        codepipeline.build_pipeline()
+
+        # Create notif topic and bind to pipeline exec events
+        topic = aws_sns.Topic(self, 'topic', topic_name=f"{self.codepipeline.pipeline.pipeline_name}-status")
+        topic.add_subscription(aws_sns_subscriptions.LambdaSubscription(self.notif_github_statuses))
+        codepipeline.pipeline.notify_on(
+            'notify-status',
+            target=topic,
+            detail_type=aws_codestarnotifications.DetailType.FULL,
+            events=[
+                aws_codepipeline.PipelineNotificationEvents.PIPELINE_EXECUTION_FAILED,
+                aws_codepipeline.PipelineNotificationEvents.PIPELINE_EXECUTION_CANCELED,
+                aws_codepipeline.PipelineNotificationEvents.PIPELINE_EXECUTION_STARTED,
+                aws_codepipeline.PipelineNotificationEvents.PIPELINE_EXECUTION_RESUMED,
+                aws_codepipeline.PipelineNotificationEvents.PIPELINE_EXECUTION_SUPERSEDED,
+                aws_codepipeline.PipelineNotificationEvents.PIPELINE_EXECUTION_SUCCEEDED
+            ]
+        )
+
+    @property
+    def notif_github_statuses(self) -> aws_lambda.Function:
+        if not self._notif_github_statuses:
+            self._notif_github_statuses = self.github_statuses()
+        return self._notif_github_statuses
+
+    def github_statuses(self, path: str='aviv_cdk/cicd/notif.py') -> aws_lambda.Function:
+        with open(path, encoding="utf8") as fp:
+            code = fp.read()
+        return aws_lambda.Function(
+            self, 'notif',
+            handler='index.lambda_handler',
+            runtime=aws_lambda.Runtime.PYTHON_3_8,
+            code=aws_lambda.InlineCode(code),
+            description='Github status with https://docs.github.com/en/rest/commits/statuses',
+            environment={
+                "GH_TOKEN": os.environ.get("GH_TOKEN", ""),
+            },
+            initial_policy=[
+                aws_iam.PolicyStatement(
+                    actions=['codepipeline:GetPipelineExecution'],
+                    resources=['arn:aws:codepipeline:*:*:*']
+                ),
+                aws_iam.PolicyStatement(
+                    actions=['logs:CreateLogGroup', 'logs:CreateLogStream', 'logs:PutLogEvents'],
+                    resources=['arn:aws:logs:*:*:*']
+                )
+            ]
+        )
