@@ -8,13 +8,14 @@ from aws_cdk import (
 
 
 class SamlProvider(aws_iam.SamlProvider):
-    ssm_parameter_name: str=''
     def __init__(
             self,
             scope: Construct,
             id: str,
             name: str,
+            metadata_document: aws_iam.SamlMetadataDocument=None,
             saml_metadata_url: str=None,
+            saml_metadata_file: str=None,
             saml_metadata_document: str=None,
             ssm_parameter_name: str=None
             ) -> None:
@@ -27,25 +28,29 @@ class SamlProvider(aws_iam.SamlProvider):
             idp_url (str, optional): [description]. Defaults to None.
             saml_metadata_document (str, optional): [description]. Defaults to None.
         """
-
-        # Load SSO SAML metadata
-        if saml_metadata_url:
-            resp = requests.get(url=saml_metadata_url)
-            saml_metadata_document = resp.text
-        if not saml_metadata_document:
+        if saml_metadata_url and not saml_metadata_document:
+            saml_metadata_document = self.from_url(url=saml_metadata_url)
+        if saml_metadata_document:
+            metadata_document = aws_iam.SamlMetadataDocument.from_xml(xml=saml_metadata_document)
+        elif saml_metadata_file:
+            metadata_document = aws_iam.SamlMetadataDocument.from_file(path=saml_metadata_file)
+        if not metadata_document:
             raise AttributeError("Need saml_metadata_url or saml_metadata_document")
 
         super().__init__(
             scope, id,
             name=name,
-            metadata_document=aws_iam.SamlMetadataDocument.from_xml(saml_metadata_document)
+            metadata_document=metadata_document
         )
-        self.ssm_parameter_name = ssm_parameter_name
         CfnOutput(self.stack, f"{self.node.id}-arn", value=self.saml_provider_arn)
-        if self.ssm_parameter_name:
-            aws_ssm.StringParameter(self.stack, f"{self.node.id}-ssm", string_value=self.saml_provider_arn, parameter_name=self.ssm_parameter_name)
-            CfnOutput(self.stack, f"{self.node.id}-ssm-name", value=self.ssm_parameter_name)
+        if ssm_parameter_name:
+            # self.ssm_parameter_name = ssm_parameter_name
+            aws_ssm.StringParameter(self.stack, f"{self.node.id}-ssm", string_value=self.saml_provider_arn, parameter_name=ssm_parameter_name)
+            CfnOutput(self.stack, f"{self.node.id}-ssm-name", value=ssm_parameter_name)
 
+    def from_url(self, url: str) -> str:
+        resp = requests.get(url=url)
+        return resp.text
 
 def SamlFederatedPrincipal(federated: str) -> aws_iam.FederatedPrincipal:
     return aws_iam.FederatedPrincipal(
