@@ -1,18 +1,19 @@
 import sys
 import logging
+from constructs import Construct
 from aws_cdk import (
+    CfnOutput,
     aws_events,
     aws_events_targets,
     aws_lambda,
-    aws_ssm,
-    core
+    aws_ssm
 )
 
 
-class Construct(core.Construct):
+class Construct(Construct):
     _layers = dict()
 
-    def __init__(self,  scope: core.Construct, id: str, *, lambdas: dict=None, layers: dict=None):
+    def __init__(self,  scope: Construct, id: str, *, lambdas: dict=None, layers: dict=None):
         super().__init__(scope, id)
         # Process and save AWS Lambda layers
         for layer_name, layer_attr in layers.items():
@@ -27,7 +28,7 @@ class Construct(core.Construct):
                 if layer in self._layers:
                     layer = self._layers[layer]
         fx = aws_lambda.Function(self, id, **attr)
-        core.CfnOutput(self, f"{id}-cfn", value=fx.function_arn)
+        CfnOutput(self, f"{id}-cfn", value=fx.function_arn)
         return fx
 
     def LayerVersion(self, id: str, *, remote_account_grant: bool=False, ssm_param: bool=True, **attr) -> aws_lambda.LayerVersion:
@@ -40,7 +41,7 @@ class Construct(core.Construct):
                 string_value=layv.layer_version_arn,
                 parameter_name=f"/layers/{id.replace('-', '/')}"
             )
-        core.CfnOutput(self, f"{id}-cfn", value=layv.from_layer_version_arn)
+        CfnOutput(self, f"{id}-cfn", value=layv.from_layer_version_arn)
         return layv
     
     def cron(self, id: str, cron: aws_events.Schedule, *, targets: list=[], event: dict=None, target_args: dict=None, event_attr: dict=None):
